@@ -22,7 +22,7 @@ import uuid
 import tempfile
 
 __author__ = "Anthony Zhang (Uberi)"
-__version__ = "3.6.0"
+__version__ = "3.6.1"
 __license__ = "BSD"
 
 try:  # attempt to use the Python 2 modules
@@ -412,12 +412,18 @@ class AudioData(object):
         # run the FLAC converter with the WAV data to get the FLAC data
         wav_data = self.get_wav_data(convert_rate, convert_width)
         flac_converter = get_flac_converter()
+        if os.name == "nt": # on Windows, specify that the process is to be started without showing a console window
+            startup_info = subprocess.STARTUPINFO()
+            startup_info.dwFlags |= subprocess.STARTF_USESHOWWINDOW # specify that the wShowWindow field of `startup_info` contains a value
+            startup_info.wShowWindow = subprocess.SW_HIDE # specify that the console window should be hidden
+        else:
+            startup_info = None # default startupinfo
         process = subprocess.Popen([
             flac_converter,
             "--stdout", "--totally-silent",  # put the resulting FLAC file in stdout, and make sure it's not mixed with any program output
             "--best",  # highest level of compression available
             "-",  # the input FLAC file contents will be given in stdin
-        ], stdin=subprocess.PIPE, stdout=subprocess.PIPE)
+        ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, startupinfo=startup_info)
         flac_data, stderr = process.communicate(wav_data)
         return flac_data
 
@@ -737,8 +743,12 @@ class Recognizer(AudioSource):
         if show_all: return actual_result
         if not isinstance(actual_result, dict) or len(actual_result.get("alternative", [])) == 0: raise UnknownValueError()
 
-        # return alternative with highest confidence score
-        best_hypothesis = max(actual_result["alternative"], key=lambda alternative: alternative["confidence"])
+        if "confidence" in actual_result["alternative"]:
+            # return alternative with highest confidence score
+            best_hypothesis = max(actual_result["alternative"], key=lambda alternative: alternative["confidence"])
+        else:
+            # when there is no confidence available, we arbitrarily choose the first hypothesis.
+            best_hypothesis = actual_result["alternative"][0]
         if "transcript" not in best_hypothesis: raise UnknownValueError()
         return best_hypothesis["transcript"]
 
